/// <reference types="node" />
import { AxiosResponse } from 'axios';
import { TorrentState, TransferInfo } from '../interfaces.js';
import { QBITTORRENT_SETTINGS } from '../utils/config.js';
export declare class QbittorrentApi {
    basePath: string;
    cookie: string;
    private client;
    private version;
    constructor(basePath: string, cookie: string);
    getAndSetVersion(): Promise<string>;
    getTorrents(hashes?: string[]): Promise<QbittorrentTorrent[]>;
    getTorrent(infohash: string): Promise<QbittorrentTorrent>;
    getTrackers(infohash: string): Promise<QbittorrentTracker[]>;
    addTags(torrents: ApiCompatibleTorrent[], tags: string[]): Promise<void>;
    setCategory(infohash: string, category: string): Promise<void>;
    resumeTorrents(torrents: ApiCompatibleTorrent[]): Promise<void>;
    pauseTorrents(torrents: QbittorrentTorrent[]): Promise<void>;
    deleteTorrentsWithFiles(torrents: ApiCompatibleTorrent[]): Promise<void>;
    addTorrent(torrentData: Buffer, category?: string): Promise<void>;
    reannounce(infohash: string): Promise<void>;
    getTransferInfo(): Promise<TransferInfo>;
}
export declare const login: (qbittorrentSettings: QBITTORRENT_SETTINGS) => Promise<AxiosResponse>;
export declare type ApiCompatibleTorrent = {
    hash: string;
};
export declare type QbittorrentTorrent = {
    name: string;
    hash: string;
    state: TorrentState;
    added_on: number;
    ratio: number;
    category: string;
    tags: string;
    size: number;
};
export declare type QbittorrentTracker = {
    status: number;
    url: string;
};
